SWDEV-271416 - Remove HIP_DYNAMIC_SHARED macro in hip
Change-Id: I12f39ea8438eb7ce76d8ffb2151b4faa93689048
[ROCm/hip-tests commit: ce2dff449d]
This commit is contained in:
@@ -49,8 +49,7 @@ __global__ void matrixTranspose_static_shared(float* out, float* in,
|
||||
|
||||
__global__ void matrixTranspose_dynamic_shared(float* out, float* in,
|
||||
const int width) {
|
||||
// declare dynamic shared memory
|
||||
HIP_DYNAMIC_SHARED(float, sharedMem)
|
||||
extern __shared__ float sharedMem[];
|
||||
|
||||
int x = hipBlockDim_x * hipBlockIdx_x + hipThreadIdx_x;
|
||||
int y = hipBlockDim_y * hipBlockIdx_y + hipThreadIdx_y;
|
||||
|
||||
Reference in New Issue
Block a user